@@ -155,7 +155,7 @@ class Excel():
 
 
     # sheet_action(func): Decorator to open up a sheet before calling 'func'
-    def sheet_action(func: Callable[[...], Any]):
+    def sheet_action(func: Callable[..., Any]):
         def check_sheet(self, sheet: Union[str, Worksheet], *args, **kwargs) -> Any:
             if (isinstance(sheet, str)):
                 sheet = self.read_sheet(sheet)
